shithub: sox

Download patch

ref: a10882c05236a639b51eedb3dfaa354e7b2b5bae
parent: 20c9d7c1310165736b529079da849f904fd1e523
author: rrt <rrt>
date: Tue Apr 10 15:27:24 EDT 2007

Rename "delete" functions to "kill" for consistency. Closes #1652035.

--- a/src/fade.c
+++ b/src/fade.c
@@ -319,7 +319,7 @@
  * Do anything required when you stop reading samples.
  *      (free allocated memory, etc.)
  */
-static int delete(eff_t effp)
+static int kill(eff_t effp)
 {
     fade_t fade = (fade_t) effp->priv;
 
@@ -382,7 +382,7 @@
   sox_fade_flow,
   sox_fade_drain,
   sox_effect_nothing,
-  delete
+  kill
 };
 
 const sox_effect_t *sox_fade_effect_fn(void)
--- a/src/mcompand.c
+++ b/src/mcompand.c
@@ -603,7 +603,7 @@
   return SOX_SUCCESS;
 }
 
-static int sox_mcompand_delete(eff_t effp)
+static int sox_mcompand_kill(eff_t effp)
 {
   compand_t c = (compand_t) effp->priv;
   comp_band_t l;
@@ -637,7 +637,7 @@
   sox_mcompand_flow,
   sox_mcompand_drain,
   sox_mcompand_stop,
-  sox_mcompand_delete
+  sox_mcompand_kill
 };
 
 const sox_effect_t *sox_mcompand_effect_fn(void)
--- a/src/pad.c
+++ b/src/pad.c
@@ -128,7 +128,7 @@
   return SOX_SUCCESS;
 }
 
-static int delete(eff_t effp)
+static int kill(eff_t effp)
 {
   pad_t p = (pad_t) effp->priv;
   unsigned i;
@@ -142,7 +142,7 @@
 {
   static sox_effect_t driver = {
     "pad", "Usage: pad {length[@position]}", SOX_EFF_MCHAN,
-    create, start, flow, drain, stop, delete
+    create, start, flow, drain, stop, kill
   };
   return &driver;
 }
--- a/src/silence.c
+++ b/src/silence.c
@@ -705,7 +705,7 @@
     return(SOX_SUCCESS);
 }
 
-static int delete(eff_t effp)
+static int kill(eff_t effp)
 {
   silence_t silence = (silence_t) effp->priv;
 
@@ -723,7 +723,7 @@
   sox_silence_flow,
   sox_silence_drain,
   sox_silence_stop,
-  delete
+  kill
 };
 
 const sox_effect_t *sox_silence_effect_fn(void)
--- a/src/sox.c
+++ b/src/sox.c
@@ -107,7 +107,7 @@
 static int drain_effect_out(void);
 static int drain_effect(unsigned);
 static void stop_effects(void);
-static void delete_effects(void);
+static void kill_effects(void);
 
 #define MAX_INPUT_FILES 32
 #define MAX_FILES MAX_INPUT_FILES + 2 /* 1 output file plus record input */
@@ -539,7 +539,7 @@
   } while (process() != SOX_EOF && !user_abort && current_input < input_count);
   else process();
 
-  delete_effects();
+  kill_effects();
 
   for (i = 0; i < file_count; ++i)
     if (files[i]->desc->clips != 0)
@@ -1363,10 +1363,10 @@
         return SOX_EOF;
     }
     if (is_always_null || ret == SOX_EFF_NULL) { /* remove from the chain */
-      int (*delete)(eff_t effp) = e->h->kill? e->h->kill: sox_effect_nothing;
+      int (*kill)(eff_t effp) = e->h->kill? e->h->kill: sox_effect_nothing;
 
-      /* No left & right delete as there is no left & right getopts */
-      delete(e);
+      /* No left & right kill as there is no left & right getopts */
+      kill(e);
       --neffects;
       for (j = i--; j < neffects; ++j) {
         efftab[j] = efftab[j + 1];
@@ -1726,16 +1726,16 @@
   }
 }
 
-static void delete_effects(void)
+static void kill_effects(void)
 {
   unsigned e;
 
   for (e = 1; e < neffects; e++) {
-    int (*delete)(eff_t effp) =
+    int (*kill)(eff_t effp) =
        efftab[e].h->kill? efftab[e].h->kill : sox_effect_nothing;
 
-    /* No left & right delete as there is no left & right getopts */
-    delete(&efftab[e]);
+    /* No left & right kill as there is no left & right getopts */
+    kill(&efftab[e]);
   }
 }
 
--- a/src/trim.c
+++ b/src/trim.c
@@ -179,7 +179,7 @@
         return (SOX_SUCCESS);
 }
 
-static int delete(eff_t effp)
+static int kill(eff_t effp)
 {
     trim_t trim = (trim_t) effp->priv;
 
@@ -210,7 +210,7 @@
   sox_trim_flow,
   sox_effect_nothing_drain,
   sox_effect_nothing,
-  delete
+  kill
 };
 
 const sox_effect_t *sox_trim_effect_fn(void)
--- a/src/skeleff.c
+++ b/src/skeleff.c
@@ -116,10 +116,10 @@
 }
 
 /*
  * Do anything required when you delete an effect.  
  *      (free allocated memory, etc.)
  */
-static int delete(eff_t effp)
+static int kill(eff_t effp)
 {
   return SOX_SUCCESS;
 }
@@ -140,7 +140,7 @@
   flow,
   drain,
   stop,
-  delete,
+  kill,
 };
 
 /*
@@ -116,10 +116,10 @@
 
 /*
- * Do anything required when you delete an effect.  
+ * Do anything required when you kill an effect.  
  *      (free allocated memory, etc.)
  */